summaryrefslogtreecommitdiffstats
path: root/kioslaves/mbox/mboxfile.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kioslaves/mbox/mboxfile.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kioslaves/mbox/mboxfile.h')
-rw-r--r--kioslaves/mbox/mboxfile.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kioslaves/mbox/mboxfile.h b/kioslaves/mbox/mboxfile.h
index b8a98973..a628e381 100644
--- a/kioslaves/mbox/mboxfile.h
+++ b/kioslaves/mbox/mboxfile.h
@@ -32,9 +32,9 @@ public:
/**
* Constructor
* @param info The urlinfo which must be used
* @param parent The MBoxProtocol parent instance, used to throw errors.
*/
- MBoxFile( const UrlInfo* info, MBoxProtocol* parent );
+ MBoxFile( const UrlInfo* info, MBoxProtocol* tqparent );
/**
* Empty destructor
@@ -61,7 +61,7 @@ protected:
const UrlInfo* const m_info;
/**
* A instance of the parent protocol, meant to throw errors if neccesairy.
*/
MBoxProtocol* const m_mbox;
};
@@ -32,9 +32,9 @@ public:
* Constructor
* @param info The urlinfo which must be used
- * @param parent The MBoxProtocol parent instance, used to throw errors.
+ * @param tqparent The MBoxProtocol tqparent instance, used to throw errors.
*/
@@ -61,7 +61,7 @@ protected:
const UrlInfo* const m_info;
/**
- * A instance of the parent protocol, meant to throw errors if neccesairy.
+ * A instance of the tqparent protocol, meant to throw errors if neccesairy.
*/
MBoxProtocol* const m_mbox;